<?php
/**
 * @package MachII
 */
/**
 * 
 */
require_once 'MachII/framework/BaseObject.php';
require_once 'MachII/framework/EventContext.php';
require_once 'MachII/framework/RequestHandler.php';
require_once 'MachII/framework/Listener.php';

/**
 * The main framework manager.
 * @package MachII
 * @author Ben Edwards <ben@ben-edwards.com>
 * @author Alan Richmond <alan@aardwolfweb.com>
 */
class MachII_framework_AppManager
{
    /**
     * Property Manager
     * @access private
     * @var MachII_framework_PropertyManager
     */
    private $_propertyManager;
    /**
     * Listener Manager
     * @access private
     * @var MachII_framework_ListenerManager
     */
    private $_listenerManager;
    /**
     * Filter Manager
     * @access private
     * @var MachII_framework_FilterManager
     */
    private $_filterManager;
    /**
     * Event Manager
     * @access private
     * @var MachII_framework_EventManager
     */
    private $_eventManager;
    /**
     * View Manager
     * @access private
     * @var MachII_framework_ViewManager
     */
    private $_viewManager;
    /**
     * Plugin Manager
     * @access private
     * @var MachII_framework_PluginManager
     */
    private $_pluginManager;
    /**
     * Request Handler
     * @access private
     * @var MachII_framework_RequestHandler
     */
    private $_requestHandler;
    
    /**
     * @uses MachII_framework_RequestHandler
     */
    public function __construct()
    {
        $this->_requestHandler = $this->createRequestHandler();
    }
    
    /**
     * Configure the component managers
     * 
     * Managers are configured in the following order:
     * <ol>
     *     <li>Property</li>
     *     <li>Listener</li>
     *     <li>Filter</li>
     *     <li>Event</li>
     *     <li>Plugin</li>
     *     <li>View</li>
     * </ol>
     */
    public function configure()
    {
        $this->getPropertyManager()->configure();
        $this->getPluginManager()->configure();
        $this->getListenerManager()->configure();
        $this->getFilterManager()->configure();
        $this->getEventManager()->configure();
        $this->getViewManager()->configure();
    }
    
    /**
     * @uses MachII_framework_EventContext
     * @return MachII_framework_EventContext
     */
    public function createEventContext()
    {
        $eventContext = new MachII_framework_EventContext($this);
        
        return $eventContext;
    }
    
    /**
     * @uses MachII_framework_RequestHandler
     * @return MachII_framework_RequestHandler
     */
    public function createRequestHandler()
    {
        $requestHandler = new MachII_framework_RequestHandler($this);
        
        return $requestHandler;
    }
    
    /**
     * @param boolean should a new request handler be created?
     * @return MachII_framework_RequestHandler
     */
    public function getRequestHandler($createNew = false)
    {
        if ($createNew) {
            return $this->createRequestHandler();
        }
        
        return $this->_requestHandler;
    }
    
    /**
     * @return MachII_framework_EventManager
     */
    public function getEventManager()
    {
        return $this->_eventManager;
    }
    
    /**
     * @param MachII_framework_EventManager
     */
    public function setEventManager(MachII_framework_EventManager $mgr)
    {
        $this->_eventManager = $mgr;
    }
    
    /**
     * @return MachII_framework_FilterManager
     */
    public function getFilterManager()
    {
        return $this->_filterManager;
    }
    
    /**
     * @param MachII_framework_FilterManager
     */
    public function setFilterManager(MachII_framework_FilterManager $mgr)
    {
        $this->_filterManager = $mgr;
    }
    
    /**
     * @return MachII_framework_ListenerManager
     */
    public function getListenerManager()
    {
        return $this->_listenerManager;
    }
    
    /**
     * @param MachII_framework_ListenerManager
     */
    public function setListenerManager(MachII_framework_ListenerManager $mgr)
    {
        $this->_listenerManager = $mgr;
    }
    
    /**
     * @return MachII_framework_PluginManager
     */
    public function getPluginManager()
    {
        return $this->_pluginManager;
    }
    
    /**
     * @param MachII_framework_PluginManager
     */
    public function setPluginManager(MachII_framework_PluginManager $mgr)
    {
        $this->_pluginManager = $mgr;
    }
    
    /**
     * @return MachII_framework_PropertyManager
     */
    public function getPropertyManager()
    {
        return $this->_propertyManager;
    }
    
    /**
     * @param MachII_framework_PropertyManager
     */
    public function setPropertyManager(MachII_framework_PropertyManager $mgr)
    {
        $this->_propertyManager = $mgr;
    }
    
    /**
     * @return MachII_framework_ViewManager
     */
    public function getViewManager()
    {
        return $this->_viewManager;
    }
    
    /**
     * @param MachII_framework_ViewManager
     */
    public function setViewManager(MachII_framework_ViewManager $mgr)
    {
        $this->_viewManager = $mgr;
    }

}
?>
