<?php
/**
 * @package Cache
 * @author Alan Richmond <alan@aardwolfweb.com>
 */
/**
 * Simple Cache Facade
 * @package Cache
 * @author Alan Richmond <alan@aardwolfweb.com>
 */
abstract class MachII_framework_Cache
{
    /**
     * @var mixed
     */
    public $cache;
    
    /**
     * @var string
     */
    public $appName;
    
    /**
     * @var array
     */
    public $options = array();
    
    
    /**
     * Constructor
     * 
     * Generally should be called in the constructor of descendents.
     * @param string
     * @param array associative array of cache options
     */
    public function __construct($appName, $options = array())
    {
        $this->appName = $appName;
        $this->options = $options;
        $this->cache   = $this->createCache();
    }
    
    /**
     * Store a variable.
     * @param string
     * @param mixed
     * @abstract
     */
    public abstract function save($name, $value);
    
    /**
     * Retrieve a variable.
     * @param string
     * @return mixed
     * @abstract
     */
    public abstract function get($varName);
    
    /**
     * Remove all items in application cache.
     * @abstract
     */
    public abstract function clear();
    
    /**
     * Initialize the cache container.
     * @abstract
     */
    protected abstract function createCache();
        
    /**
     * @param mixed
     */
    public function setCache($cache)
    {
        $this->cache = $cache;
    }
    
    /**
     * @return mixed
     */
    public function getCache()
    {
        return $this->cache;
    }
    
    /**
     * @param string
     */
    public function setAppName($appName)
    {
        $this->appName = $appName;
    }
    
    /**
     * @return string
     */
    public function getAppName()
    {
        return $this->appName;
    }
    
    /**
     * @param array
     */
    public function setOptions($options)
    {
        $this->options = $options;
    }
    
    /**
     * @return array
     */
    public function getOptions()
    {
        return $this->options;
    }
    
    /**
     * @param string
     * @param mixed
     */
    public function setOption($name, $value)
    {
        $this->options[$name] = $value;
    }
    
    /**
     * @param string
     * return mixed
     */
    public function getOption($name)
    {
        return $this->options[$name];
    }

}

?>
