<?php
/**
 * @package MachII
 */
/**
 * Manages defined properties.
 * @package MachII
 * @author Ben Edwards <ben@ben-edwards.com>
 * @author Alan Richmond <alan@aardwolfweb.com>
 */
class MachII_framework_PropertyManager
{
    /**
     * @var MachII_framework_AppManager
     * @access private
     */
    private $_appManager;
    
    /**
     * @var array associative array of defined properties
     * @access private
     */
    private $_properties = array(
        'defaultEvent'        => 'defaultEvent',
        'exceptionEvent'      => 'exceptionEvent',
        'applicationRoot'     => '.',
        'eventParameter'      => 'event',
        'parameterPrecedence' => 'form',
        'maxEvents'           => 10
    );
    
    
    /**
     * @param SimpleXMLElement
     * @param MachII_framework_AppManager
     */
    public function __construct(SimpleXMLElement $configXml, MachII_framework_AppManager $appManager)
    {
        $this->setAppManager($appManager);
        
        $properties = $configXml->xpath('//property');
        if (empty($properties)) {
            return;
        }
        foreach ($properties as $property) {
                $this->_properties[(string) $property['name']] = (string) $property['value'];
        }
    }
    
    /**
     * Configure the property manager.
     * @internal doesn't do anything at this time.
     */
    public function configure() {}
    
    /**
     * @param string
     * @return mixed|void
     */
    public function getProperty($propertyName)
    {
        if (isset($this->_properties[$propertyName])) {
            return $this->_properties[$propertyName];
        }
    }
    
    /**
     * @param string
     * @param mixed
     */
    public function setProperty($propertyName, $propertyValue)
    {
        $this->_properties[$propertyName] = $propertyValue;
    }
    
    /**
     * @return array associative array of defined properties
     */
    public function getProperties()
    {
        return $this->_properties;
    }
    
    /**
     * @param string
     * @return boolean
     */
    public function hasProperty($propertyName)
    {
        return isset($this->_properties[$propertyName]);
    }
    
    /**
     * @param MachII_framework_AppManager
     */
    public function setAppManager(MachII_framework_AppManager $appManager)
    {
        $this->_appManager = $appManager;
    }
    
    /**
     * @return MachII_framework_AppManager
     */
    public function getAppManager()
    {
        return $this->_appManager;
    }

}

?>
