<?php
/**
 * @package MachII
 * @subpackage Commands
 */
/**
 * An EventCommand for filtering events.
 * @package MachII
 * @subpackage Commands
 * @author Ben Edwards <ben@ben-edwards.com>
 * @author Alan Richmond <alan@aardwolfweb.com>
 */
class MachII_framework_commands_FilterCommand extends MachII_framework_EventCommand
{
    /**
     * @access private
     * @var MachII_framework_EventFilter MachII_framework_EventFilter descendent
     */
    private $_filter;
    /**
     * @access private
     * @var array an associative array
     */
    private $_paramArgs = array();
    
    
    /**
     * @param MachII_framework_EventFilter MachII_framework_EventFilter descendent
     * @param array an associative array
     */
    public function __construct(MachII_framework_EventFilter $filter, $paramArgs = array())
    {
        $this->_setFilter($filter);
        $this->_setParamArgs($paramArgs);
    }
    
    /**
     * @param MachII_framework_Event MachII_framework_Event descendent
     * @param MachII_framework_EventContext
     * @return boolean
     */
    public function execute(MachII_framework_Event $event, MachII_framework_EventContext $eventContext)
    {
        $continue = $this->_getFilter()->filterEvent($event, $eventContext, $this->_getParamArgs());
        
        return $continue;
    }
    
    /**
     * @access private
     * @param MachII_framework_EventFilter MachII_framework_EventFilter descendent
     */
    private function _setFilter(MachII_framework_EventFilter $filter)
    {
        $this->_filter = $filter;
    }
    
    /**
     * @access private
     * @return MachII_framework_EventFilter MachII_framework_EventFilter descendent
     */
    private function _getFilter()
    {
        return $this->_filter;
    }
    
    /**
     * @access private
     * @param array an associative array
     */
    private function _setParamArgs($paramArgs)
    {
        $this->_paramArgs = $paramArgs;
    }
    
    /**
     * @access private
     * @return array an associative array
     */
    private function _getParamArgs()
    {
        return $this->_paramArgs;
    }

}

?>
