<?php
/**
 * @package MachII
 * @subpackage Commands
 */
/**
 * An EventCommand for processing an EventFilter.
 * @package MachII
 * @subpackage Commands
 * @author Ben Edwards <ben@ben-edwards.com>
 * @author Alan Richmond <alan@aardwolfweb.com>
 */
class MachII_framework_commands_ViewPageCommand extends MachII_framework_EventCommand
{
    /**
     * @access private
     * @var string
     */
    private $_viewName;
    
    /**
     * @access private
     * @var string a string representation of a variable name
     */
    private $_contentKey;
    
    /**
     * @access private
     * @var boolean
     */
    private $_append;
    
    
    /**
     * @param string
     * @param string a string representation of a variable name
     */
    public function __construct($viewName, $contentKey = null, $append = false)
    {
        $this->_setViewName($viewName);
        $this->_setContentKey($contentKey);
        $this->_setAppend($append);
    }
    
    /**
     * @param MachII_framework_Event or a MachII_framework_Event descendent
     * @param MachII_framework_EventContext
     * @return true
     */
    public function execute(MachII_framework_Event $event, MachII_framework_EventContext $eventContext)
    {
        $eventContext->displayView($event, $this->_getViewName(), $this->_getContentKey(), $this->_getAppend());
        
        return true;
    }
    
    /**
     * @access private
     * @param boolean
     */
    private function _setAppend($append)
    {
        $this->_append = $append;
    }
    
    /**
     * @access private
     * @return boolean
     */
    private function _getAppend()
    {
        return $this->_append;
    }
    
    /**
     * @access private
     * @param string
     */
    private function _setViewName($viewName)
    {
        $this->_viewName = $viewName;
    }
    
    /**
     * @access private
     * @return string
     */
    private function _getViewName()
    {
        return $this->_viewName;
    }
    
    /**
     * @access private
     * @param string a string representation of a variable name
     */
    private function _setContentKey($contentKey)
    {
        $this->_contentKey = $contentKey;
    }
    
    /**
     * @access private
     * @return string a string representation of a variable name
     */
    private function _getContentKey()
    {
        return $this->_contentKey;
    }
    
    /**
     * @access private
     * @return boolean
     */
    private function _hasContentKey()
    {
        return !is_null($this->_getContentKey);
    }

}

?>
